@@ -42,6 +42,7 @@ from openpyxl.shared.date_time import SharedDate
 from openpyxl.shared.exc import CellCoordinatesException, \
         ColumnStringIndexException, DataTypeException
 from openpyxl.style import NumberFormat
+from openpyxl.shared import NUMERIC_TYPES
 
 # constants
 COORD_RE = re.compile('^[$]?([A-Z]+)[$]?(\d+)$')
@@ -55,7 +56,11 @@ def coordinate_from_string(coord_string):
         msg = 'Invalid cell coordinates (%s)' % coord_string
         raise CellCoordinatesException(msg)
     column, row = match.groups()
-    return (column, int(row))
+    row = int(row)
+    if not row:
+        msg = "There is no row 0 (%s)" % coord_string
+        raise CellCoordinatesException(msg)
+    return (column, row)
 
 
 def absolute_coordinate(coord_string):
@@ -68,7 +73,7 @@ def absolute_coordinate(coord_string):
         return '$%s$%s' % (parts[0], parts[1])
 
 
-def column_index_from_string(column, fast = False):
+def column_index_from_string(column, fast=False):
     """Convert a column letter into a column number (e.g. B -> 2)
     
     Excel only supports 1-3 letter column names from A -> ZZZ, so we
@@ -160,11 +165,12 @@ class Cell(object):
                    TYPE_NULL, TYPE_INLINE, TYPE_ERROR]
 
     RE_PATTERNS = {
-        'percentage': re.compile('^\-?[0-9]*\.?[0-9]*\s?\%$'),
-        'time': re.compile('^(\d|[0-1]\d|2[0-3]):[0-5]\d(:[0-5]\d)?$'),
-        'numeric': re.compile('^\-?([0-9]+\\.?[0-9]*|[0-9]*\\.?[0-9]+)((E|e)\-?[0-9]+)?$'), }
+        'percentage': re.compile(r'^\-?[0-9]*\.?[0-9]*\s?\%$'),
+        'time': re.compile(r'^(\d|[0-1]\d|2[0-3]):[0-5]\d(:[0-5]\d)?$'),
+        'numeric': re.compile(r'^-?([\d]|[\d]+\.[\d]*|\.[\d]+|[1-9][\d]+\.?[\d]*)((E|e)-?[\d]+)?$'),
+        }
 
-    def __init__(self, worksheet, column, row, value = None):
+    def __init__(self, worksheet, column, row, value=None):
         self.column = column.upper()
         self.row = row
         # _value is the stored value, while value is the displayed value
@@ -176,13 +182,18 @@ class Cell(object):
         self.parent = worksheet
         self.xf_index = 0
 
+    @property
+    def encoding(self):
+        return self.parent.encoding
+
     def __repr__(self):
         return u"<Cell %s.%s>" % (self.parent.title, self.get_coordinate())
 
     def check_string(self, value):
         """Check string coding, length, and line break character"""
         # convert to unicode string
-        value = unicode(value)
+        if not isinstance(value, unicode):
+            value = unicode(value, self.encoding)
         # string must never be longer than 32,767 characters
         # truncate if necessary
         value = value[:32767]
@@ -193,19 +204,19 @@ class Cell(object):
 
     def check_numeric(self, value):
         """Cast value to int or float if necessary"""
-        if not isinstance(value, (int, float)):
+        if not isinstance(value, NUMERIC_TYPES):
             try:
                 value = int(value)
             except ValueError:
                 value = float(value)
         return value
 
-    def set_value_explicit(self, value = None, data_type = TYPE_STRING):
+    def set_value_explicit(self, value=None, data_type=TYPE_STRING):
         """Coerce values according to their explicit type"""
         type_coercion_map = {
             self.TYPE_INLINE: self.check_string,
             self.TYPE_STRING: self.check_string,
-            self.TYPE_FORMULA: unicode,
+            self.TYPE_FORMULA: self.check_string,
             self.TYPE_NUMERIC: self.check_numeric,
             self.TYPE_BOOL: bool, }
         try:
@@ -222,7 +233,7 @@ class Cell(object):
             data_type = self.TYPE_NULL
         elif value is True or value is False:
             data_type = self.TYPE_BOOL
-        elif isinstance(value, (int, float)):
+        elif isinstance(value, NUMERIC_TYPES):
             data_type = self.TYPE_NUMERIC
         elif not value:
             data_type = self.TYPE_STRING
@@ -255,13 +266,13 @@ class Cell(object):
             # time detection
             time_search = self.RE_PATTERNS['time'].match(value)
             if time_search:
-                sep_count = value.count(':') #pylint: disable-msg=E1103
+                sep_count = value.count(':') #pylint: disable=E1103
                 if sep_count == 1:
-                    hours, minutes = [int(bit) for bit in value.split(':')] #pylint: disable-msg=E1103
+                    hours, minutes = [int(bit) for bit in value.split(':')] #pylint: disable=E1103
                     seconds = 0
                 elif sep_count == 2:
                     hours, minutes, seconds = \
-                            [int(bit) for bit in value.split(':')] #pylint: disable-msg=E1103
+                            [int(bit) for bit in value.split(':')] #pylint: disable=E1103
                 days = (hours / 24.0) + (minutes / 1440.0) + \
                         (seconds / 86400.0)
                 self.set_value_explicit(days, self.TYPE_NUMERIC)
@@ -275,7 +286,7 @@ class Cell(object):
                     isinstance(value, datetime.datetime):
                 value = datetime.datetime.combine(value, datetime.time())
             if isinstance(value, datetime.datetime):
-                value = SharedDate().datetime_to_julian(date = value)
+                value = SharedDate().datetime_to_julian(date=value)
                 self.set_value_explicit(value, self.TYPE_NUMERIC)
                 self._set_number_format(NumberFormat.FORMAT_DATE_YYYYMMDD2)
                 return True
@@ -293,7 +304,7 @@ class Cell(object):
         self.bind_value(value)
 
     value = property(_get_value, _set_value,
-            doc = 'Get or set the value held in the cell.\n\n'
+            doc='Get or set the value held in the cell.\n\n'
             ':rtype: depends on the value (string, float, int or '
             ':class:`datetime.datetime`)')
 
@@ -312,7 +323,7 @@ class Cell(object):
                 self._hyperlink_rel.target or ''
 
     hyperlink = property(_get_hyperlink, _set_hyperlink,
-            doc = 'Get or set the hyperlink held in the cell.  '
+            doc='Get or set the hyperlink held in the cell.  '
             'Automatically sets the `value` of the cell with link text, '
             'but you can modify it afterwards by setting the '
             '`value` property, and the hyperlink will remain.\n\n'
@@ -331,7 +342,7 @@ class Cell(object):
     @property
     def has_style(self):
         """Check if the parent worksheet has a style for this cell"""
-        return self.get_coordinate() in self.parent._styles #pylint: disable-msg=W0212
+        return self.get_coordinate() in self.parent._styles #pylint: disable=W0212
 
     @property
     def style(self):
@@ -349,7 +360,7 @@ class Cell(object):
         :rtype: string
         """
         return '%s%s' % (self.column, self.row)
-    
+
     @property
     def address(self):
         """Return the coordinate string for this cell (e.g. 'B12')
@@ -358,7 +369,7 @@ class Cell(object):
         """
         return self.get_coordinate()
 
-    def offset(self, row = 0, column = 0):
+    def offset(self, row=0, column=0):
         """Returns a cell location relative to this cell.
 
         :param row: number of rows to offset
@@ -370,7 +381,7 @@ class Cell(object):
         :rtype: :class:`openpyxl.cell.Cell`
         """
         offset_column = get_column_letter(column_index_from_string(
-                column = self.column) + column)
+                column=self.column) + column)
         offset_row = self.row + row
         return self.parent.cell('%s%s' % (offset_column, offset_row))
 
@@ -381,4 +392,4 @@ class Cell(object):
         """
         return (self.has_style
                 and self.style.number_format.is_date_format()
-                and isinstance(self._value, (int, float)))
+                and isinstance(self._value, NUMERIC_TYPES))
